@@ -1,5 +1,3 @@
-from importlib import util
-
 import matplotlib as mpl
 from pandas.plotting import register_matplotlib_converters
 
@@ -21,7 +19,9 @@ __all__ = [
 mpl.rcParams['agg.path.chunksize'] = 10000
 register_matplotlib_converters()
 
-if util.find_spec('colored_traceback') is not None:
+try:
     import colored_traceback
 
     colored_traceback.add_hook(always=True)
+except ImportError:
+    pass
