@@ -4,6 +4,11 @@ from adcircpy.outputs.base import SurfaceOutput
 class Maxele(SurfaceOutput):
     _filetype = 'maxele'
 
+
+class MaximumElevationTimes(SurfaceOutput):
+    _filetype = 'time_of_maxele'
+
+
 # import numpy as np
 # import pathlib
 # from netCDF4 import Dataset
